function love.load()
  --run
  phase = "edit"

  love.window.showMessageBox("Info","Welcome!\n\nLeft click and drag to draw walls.\nRight click and drag to remove walls.\nYou spawn at the red and have to get to the green, so don't block these off!\nHit enter when you're ready to begin the race!\nFeel free to resize the window.\n\nWhen in game, press or hold W,A,S,D to move.\nThe lava will chase you after 3 seconds and moves SLIGHTLY faster than you.\nGet to the green quick!")

  moveSound = love.audio.newSource("sfx/move.wav")
  lavaSound = love.audio.newSource("sfx/lava.wav")

  score = 0
  level = 0

  map = {}

  w,h = love.graphics.getDimensions()
  sx = w/64
  sy = h/64

  cx, cy = love.mouse.getPosition()
  cx = cx*sx
  cy = cy*sy
  cx = round(cx*4)
  cy = round(cy*4)

  x = 1
  y = 0
  t2m = 0.2
  lavaTime = 1

  bindKeys()
  --gen random map (temp)
  for i = 1, 16 do
    map[i] = {}
    for k = 1, 16 do
      map[i][k] = {}
      map[i][k].val = 0
      map[i][k].release = false
    end
  end

  map[2][2].val = 2
  x = 1
  y = 1
  map[15][15].val = 3
end

function love.draw()
  love.graphics.push()
  love.graphics.scale(sx,sy)

  if phase == "game" then
    for i = 1, 16 do
      for k = 1, 16 do
        if i-1 == x and y == k-1 then
          love.graphics.setColor(0,200,0)
        elseif map[i][k].val == 2 then
          love.graphics.setColor(200,0,0)
        elseif map[i][k].val == 3 then
          love.graphics.setColor(0,100,0)
        else
            love.graphics.setColor(map[i][k].val*255,map[i][k].val*255,map[i][k].val*255)
        end
        love.graphics.rectangle("fill",(i-1)*4,(k-1)*4,4,4)
      end
    end
  elseif phase == "edit" then --level editor

    for i = 1, 16 do
      for k = 1, 16 do
        if cx == i-1 and cy == k-1 then
          love.graphics.setColor(0,0,200)
        elseif map[i][k].val == 2 then
          love.graphics.setColor(200,0,0)
        elseif map[i][k].val == 3 then
          love.graphics.setColor(0,100,0)
        else
          love.graphics.setColor(map[i][k].val*255,map[i][k].val*255,map[i][k].val*255)
        end
        love.graphics.rectangle("fill",(i-1)*4,(k-1)*4,4,4)
      end
    end

  --  love.graphics.setColor(255,255,255)
  --  love.graphics.setFont(font)
  --  love.graphics.print("Draw map with L/R mouse\nPress enter to start\nYou are green, run to yellow quick!")

  end
  love.graphics.pop()
end

function love.update(dt)
  if phase == "game" then
    t2m = t2m - 1*dt
    lavaTime = lavaTime - 1*dt
    if lavaTime < 0 then
      local lavaSound = love.audio.newSource("sfx/lava.wav")
      love.audio.play(lavaSound)
      processLava()
      lavaTime = 0.18
    end

    if t2m < 0 then
      local curx = x
      local cury = y
      if love.keyboard.isDown(KEY_UP) then
        local moveSound = love.audio.newSource("sfx/move.wav")
        love.audio.play(moveSound)
        y = y - 1
        t2m = 0.2
      elseif love.keyboard.isDown(KEY_DOWN) then
        local moveSound = love.audio.newSource("sfx/move.wav")
        love.audio.play(moveSound)
        y = y + 1
        t2m = 0.2
      elseif love.keyboard.isDown(KEY_LEFT) then
        local moveSound = love.audio.newSource("sfx/move.wav")
        love.audio.play(moveSound)
        x = x - 1
        t2m = 0.2
      elseif love.keyboard.isDown(KEY_RIGHT) then
        local moveSound = love.audio.newSource("sfx/move.wav")
        love.audio.play(moveSound)
        x = x + 1
        t2m = 0.2
      end

      if map[x+1][y+1].val == 1 then
        x = curx
        y = cury
      end

      if map[x+1][y+1].val == 3 then
        wins = love.audio.newSource("sfx/win.wav")
        love.audio.play(wins)
        love.window.showMessageBox("debug","WIN!")

        phase = "edit"
        for i = 2, 15 do
          for k = 2, 15 do
          --  love.window.showMessageBox("debug",i..", "..k)
            if map[i][k].val == 2 then
              map[i][k].val = 0
            end
          end
        end

        map[2][2].val = 2
        x = 1
        y = 1
        map[15][15].val = 3
      end
    end
  elseif phase == "edit" then
    cx, cy = love.mouse.getPosition()
    cx = cx/sx
    cy = cy/sy
    cx = round(cx/4-0.5)
    cy = round(cy/4-0.5)

    if love.mouse.isDown(1) then
      if cx+1 > -1 and cy+1 > -1 then
        if map[cx+1][cy+1].release == false then
          map[cx+1][cy+1].val = 1
        end
      end
    end

    if love.mouse.isDown(2) then
      if cx+1 > -1 and cy+1 > -1 then
        if map[cx+1][cy+1].release == false then
          map[cx+1][cy+1].val = 0
        end
      end
    end
  end
end

function love.keypressed(key)

  if key == "return" then
    phase = "game"
    map[2][2].val = 2
    x = 1
    y = 1
    map[15][15].val = 3
    lavaTime = 3
  end

end

function love.mousereleased()
  for i = 1, 16 do
    for k = 1, 16 do
      map[i][k].release = false
    end
  end
end

function processLava()
  for i = 2, 15 do
    for k = 2, 15 do
    --  love.window.showMessageBox("debug",i..", "..k)
      if map[i][k].val == 2 then
        if map[i+1][k].val == 0 then
          map[i+1][k].val = 4
          --love.window.showMessageBox("debug",i..", "..k)
        end
       if map[i-1][k].val == 0 then
          map[i-1][k].val = 4
        --  love.window.showMessageBox("debug",i..", "..k)
       end
        if map[i][k+1].val == 0 then
          map[i][k+1].val = 4
        --  love.window.showMessageBox("debug",i..", "..k)
        end
        if map[i][k-1].val == 0 then
          map[i][k-1].val = 4
        --  love.window.showMessageBox("debug",i..", "..k)
        end
      end
    end
  end

    for i = 2, 15 do
      for k = 2, 15 do
      --  love.window.showMessageBox("debug",i..", "..k)
        if map[i][k].val == 4 then
          map[i][k].val = 2
        end
      end
  end

  if map[x+1][y+1].val == 2 then
    love.window.showMessageBox("debug","LOSE!")
    phase = "edit"
    for i = 2, 15 do
      for k = 2, 15 do
      --  love.window.showMessageBox("debug",i..", "..k)
        if map[i][k].val == 2 then
          map[i][k].val = 0
        end
      end
    end

    map[2][2].val = 2
    x = 1
    y = 1
    map[15][15].val = 3
  end
end

function bindKeys()
  KEY_UP = "w"
  KEY_DOWN = "s"
  KEY_LEFT = "a"
  KEY_RIGHT = "d"
end

function round(x)
  if x%2 ~= 0.5 then
    return math.floor(x+0.5)
  end
  return x-0.5
end

function love.resize(w,h)
  sx = w/64
  sy = h/64
end
